Checks if a blank line should be added below either all selected rows or the first selected row.
Usage
is_blank_line_needed_below(
where = c("last row", "first row"),
context = rs_get_context()
)Checks if a blank line should be added below either all selected rows or the first selected row.
is_blank_line_needed_below(
where = c("last row", "first row"),
context = rs_get_context()
)