Check if a blank line is needed above.
Source:R/is_blank_line_needed_above.R
is_blank_line_needed_above.RdCheck if a blank line should be added above the selection.
Usage
is_blank_line_needed_above(context = rs_get_context())
R/is_blank_line_needed_above.R
is_blank_line_needed_above.RdCheck if a blank line should be added above the selection.
is_blank_line_needed_above(context = rs_get_context())