Enclose selection of text with indicated symbols.
Source:R/rs_enclose_selection_with.R
rs_enclose_selection_with.RdEnclose selection of text with certain symbols which usually have special meaning in R Markdown files.
Usage
rs_enclose_selection_with(
symbol = "",
symbol_before = symbol,
symbol_after = symbol,
trim = FALSE,
context = rs_get_context()
)Arguments
- symbol
(character) A sequence of symbols to add on both sides of selection.
- symbol_before
(character) A sequence of symbols to before the selection (overrides value of
symbol).- symbol_after
(character) A sequence of symbols to add after the selection (overrides value of
symbol).- trim
(logical) Flag if whitespace should be trimmed from both sides of the selection.
- context
(class
document_context)
Object with context of active RStudio document.