R/rs_get_selection.R
rs_get_row_lengths.Rd
Calculate number of characters in each selected row.
rs_get_row_lengths(row, end_row = NULL, context = rs_get_context())
(numeric) Index of the first row of interest of a vector of row indices.
(numeric | NULL) Index of the last row of interest or NULL.
NULL
(class document_context) Object with context of active RStudio document.
document_context
An integer vector with number of characters in each selection.