rs_get_row_range() gets range of the indicated row from the beginning to the end of the line (excluding the new line symbol).rs_get_row_range_w_newline() gets range of the indicated row from the beggining of the line to the beginning to the next line.rs_get_first_selected_row_range() gets range of the first selected line.
Usage
rs_get_row_range(row, context = rs_get_context())
rs_get_row_ranges(row, context = rs_get_context())
rs_get_row_range_w_newline(row)
rs_get_first_selected_row_range(
include_newline = FALSE,
context = rs_get_context()
)