Insert text at the beginning of the first selected row.
Source:R/rs_insert_before_first_selected_row.R
rs_insert_before_first_selected_row.RdInsert text at the beginning of the first selected row.
Usage
rs_insert_before_first_selected_row(
text = "",
ensure_blank_above = FALSE,
context = rs_get_context()
)