Get the text in either the first selection or all selections.
Usage
rs_get_selection_text(
selection = c("all", "first", "last"),
as_list = FALSE,
context = rs_get_context()
)Get the text in either the first selection or all selections.
rs_get_selection_text(
selection = c("all", "first", "last"),
as_list = FALSE,
context = rs_get_context()
)