Get the text in either the first selection or all selections.
rs_get_selection_text(
selection = c("all", "first", "last"),
as_list = FALSE,
context = rs_get_context()
)(string)
String that indicates, which selection should be extracted.
(logical)
Flag, if result should be a list, if selection is either
"first" or "last".
(class document_context)
Object with context of active RStudio document.
A character vector.