R/rs_insert_before_first_selected_row.R
rs_insert_before_first_selected_row.RdInsert text at the beginning of the first selected row.
rs_insert_before_first_selected_row(
text = "",
ensure_blank_above = FALSE,
context = rs_get_context()
)(character) The text to insert.
(logical)
If TRUE, inserts blank line above the selection if the line is not blank.
If FALSE, no blank line is added.
(class document_context)
Object with context of active RStudio document.